@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include "pangofc-decoder.h"
 
 G_DEFINE_ABSTRACT_TYPE (PangoFcDecoder, pango_fc_decoder, G_TYPE_OBJECT)
@@ -70,8 +70,8 @@ pango_fc_decoder_get_charset (PangoFcDecoder *decoder,
  * glyph is most convenient for it. (Usually whatever glyph is directly
  * in the fonts character map table.)
  *
- * Return value: the glyph index, or 0 if the glyph isn't covered
- *  by the font.
+ * Return value: the glyph index, or 0 if the glyph isn't
+ * covered by the font.
  *
  * Since: 1.6
  **/
