@@ -22,7 +22,7 @@
 /* Size of fontset cache */
 #define FONTSET_CACHE_SIZE 64
 
-#include <config.h>
+#include "config.h"
 #include <math.h>
 
 #include "pango-context.h"
@@ -1278,10 +1278,9 @@ pango_fc_font_map_clear_fontset_cache (PangoFcFontMap *fcfontmap)
  *
  * Clear all cached information and fontsets for this font map;
  * this should be called whenever there is a change in the
- * output of the default_substitute() virtual function.
- *
- * This function is intended to be used only by backend implementations
- * deriving from #PangoFcFontmap.
+ * output of the default_substitute() virtual function of the
+ * font map, or if fontconfig has been reinitialized to new
+ * configuration.
  *
  * Since: 1.4
  **/
@@ -1379,7 +1378,7 @@ _pango_fc_font_map_fc_to_coverage (FcCharSet *charset)
 	  FcChar32  bits = map[i];
 	  FcChar32  base = ucs4 + i * 32;
 	  int b = 0;
-	  bits = map[i];
+
 	  while (bits)
 	    {
 	      if (bits & 1)
@@ -1416,6 +1415,9 @@ _pango_fc_font_map_fc_to_coverage (FcCharSet *charset)
  * needed for correct operation on the #PangoContext after calling
  * this function.
  *
+ * As of Pango 1.20 this function is deprecated.
+ * Use pango_font_map_create_context() instead.
+ *
  * Return value: a new #PangoContext
  *
  * Since: 1.4
@@ -1423,10 +1425,9 @@ _pango_fc_font_map_fc_to_coverage (FcCharSet *charset)
 PangoContext *
 pango_fc_font_map_create_context (PangoFcFontMap *fcfontmap)
 {
-  PangoContext *context = pango_context_new ();
-  pango_context_set_font_map (context, PANGO_FONT_MAP (fcfontmap));
+  g_return_val_if_fail (PANGO_IS_FC_FONT_MAP (fcfontmap), NULL);
 
-  return context;
+  return pango_font_map_create_context (PANGO_FONT_MAP (fcfontmap));
 }
 
 static void
