@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -34,6 +34,7 @@
 #include "pango-engine-private.h"
 #include "pango-fontmap.h"
 #include "pango-impl-utils.h"
+#include "modules.h"
 
 #undef PANGO_DISABLE_DEPRECATED
 
@@ -278,9 +279,18 @@ pango_x_font_map_for_display (Display *display)
   char **xfontnames;
   int num_fonts, i;
   int screen;
+  static gboolean registered_modules = FALSE;
 
   g_return_val_if_fail (display != NULL, NULL);
 
+  if (!registered_modules)
+    {
+      registered_modules = TRUE;
+
+      for (i = 0; _pango_included_x_modules[i].list; i++)
+	pango_module_register (&_pango_included_x_modules[i]);
+    }
+
   /* Make sure that the type system is initialized */
   g_type_init ();
 
@@ -374,7 +384,12 @@ pango_x_font_map_finalize (GObject *object)
 
   pango_x_font_cache_free (xfontmap->font_cache);
 
-  /* FIXME: Lots more here */
+  /* FIXME: None of these hashtables free their key/values
+  g_hash_table_destroy (xfontmap->families);
+  g_hash_table_destroy (xfontmap->size_infos);
+  g_hash_table_destroy (xfontmap->to_atom_cache);
+  g_hash_table_destroy (xfontmap->from_atom_cache);
+  */
 
   fontmaps = g_list_remove (fontmaps, xfontmap);
 
@@ -640,7 +655,7 @@ pango_x_get_coverage_win (PangoXFontMap *xfontmap)
 	    XCreateWindow (persistant_display,
 			   DefaultRootWindow (persistant_display),
 			   -100, -100, 10, 10, 0, 0,
-			   InputOnly, CopyFromParent,
+			   InputOnly, (Visual *)CopyFromParent,
 			   CWOverrideRedirect, &attr);
 
 	  XChangeProperty (persistant_display,
@@ -1100,7 +1115,7 @@ pango_x_insert_font (PangoXFontMap *xfontmap,
   size_info = g_hash_table_lookup (xfontmap->size_infos, identifier);
   if (!size_info)
     {
-      size_info = g_new (PangoXSizeInfo, 1);
+      size_info = g_slice_new (PangoXSizeInfo);
       size_info->identifier = identifier;
       size_info->xlfds = NULL;
 
